@@ -68,6 +68,7 @@
 #define NM_DBUS_INTERFACE_DEVICE_VXLAN      NM_DBUS_INTERFACE_DEVICE ".Vxlan"
 #define NM_DBUS_INTERFACE_DEVICE_GRE        NM_DBUS_INTERFACE_DEVICE ".Gre"
 #define NM_DBUS_INTERFACE_DEVICE_IP_TUNNEL  NM_DBUS_INTERFACE_DEVICE ".IPTunnel"
+#define NM_DBUS_INTERFACE_DEVICE_STATISTICS NM_DBUS_INTERFACE_DEVICE ".Statistics"
 
 #define NM_DBUS_INTERFACE_SETTINGS        "org.freedesktop.NetworkManager.Settings"
 #define NM_DBUS_PATH_SETTINGS             "/org/freedesktop/NetworkManager/Settings"
@@ -103,7 +104,7 @@ typedef enum {
 	NM_STATE_CONNECTING       = 40,
 	NM_STATE_CONNECTED_LOCAL  = 50,
 	NM_STATE_CONNECTED_SITE   = 60,
-	NM_STATE_CONNECTED_GLOBAL = 70
+	NM_STATE_CONNECTED_GLOBAL = 70,
 } NMState;
 
 /**
@@ -118,11 +119,11 @@ typedef enum {
  *   appears to be able to reach the full Internet.
  */
 typedef enum {
-	NM_CONNECTIVITY_UNKNOWN,
-	NM_CONNECTIVITY_NONE,
-	NM_CONNECTIVITY_PORTAL,
-	NM_CONNECTIVITY_LIMITED,
-	NM_CONNECTIVITY_FULL
+	NM_CONNECTIVITY_UNKNOWN = 0,
+	NM_CONNECTIVITY_NONE    = 1,
+	NM_CONNECTIVITY_PORTAL  = 2,
+	NM_CONNECTIVITY_LIMITED = 3,
+	NM_CONNECTIVITY_FULL    = 4,
 } NMConnectivityState;
 
 /**
@@ -237,7 +238,7 @@ typedef enum { /*< flags >*/
  **/
 typedef enum { /*< underscore_name=nm_802_11_ap_flags, flags >*/
 	NM_802_11_AP_FLAGS_NONE    = 0x00000000,
-	NM_802_11_AP_FLAGS_PRIVACY = 0x00000001
+	NM_802_11_AP_FLAGS_PRIVACY = 0x00000001,
 } NM80211ApFlags;
 
 /**
@@ -276,7 +277,7 @@ typedef enum { /*< underscore_name=nm_802_11_ap_security_flags, flags >*/
 	NM_802_11_AP_SEC_GROUP_TKIP      = 0x00000040,
 	NM_802_11_AP_SEC_GROUP_CCMP      = 0x00000080,
 	NM_802_11_AP_SEC_KEY_MGMT_PSK    = 0x00000100,
-	NM_802_11_AP_SEC_KEY_MGMT_802_1X = 0x00000200
+	NM_802_11_AP_SEC_KEY_MGMT_802_1X = 0x00000200,
 } NM80211ApSecurityFlags;
 
 /**
@@ -296,9 +297,9 @@ typedef enum { /*< underscore_name=nm_802_11_ap_security_flags, flags >*/
  **/
 typedef enum { /*< underscore_name=nm_802_11_mode >*/
 	NM_802_11_MODE_UNKNOWN = 0,
-	NM_802_11_MODE_ADHOC,
-	NM_802_11_MODE_INFRA,
-	NM_802_11_MODE_AP
+	NM_802_11_MODE_ADHOC   = 1,
+	NM_802_11_MODE_INFRA   = 2,
+	NM_802_11_MODE_AP      = 3,
 } NM80211Mode;
 
 /**
@@ -353,7 +354,7 @@ typedef enum {
 	NM_WIMAX_NSP_NETWORK_TYPE_UNKNOWN         = 0,
 	NM_WIMAX_NSP_NETWORK_TYPE_HOME            = 1,
 	NM_WIMAX_NSP_NETWORK_TYPE_PARTNER         = 2,
-	NM_WIMAX_NSP_NETWORK_TYPE_ROAMING_PARTNER = 3
+	NM_WIMAX_NSP_NETWORK_TYPE_ROAMING_PARTNER = 3,
 } NMWimaxNspNetworkType;
 
 /**
@@ -407,7 +408,7 @@ typedef enum {
 	NM_DEVICE_STATE_SECONDARIES  = 90,
 	NM_DEVICE_STATE_ACTIVATED    = 100,
 	NM_DEVICE_STATE_DEACTIVATING = 110,
-	NM_DEVICE_STATE_FAILED       = 120
+	NM_DEVICE_STATE_FAILED       = 120,
 } NMDeviceState;
 
 /**
@@ -479,69 +480,69 @@ typedef enum {
  * Device state change reason codes
  */
 typedef enum {
-	NM_DEVICE_STATE_REASON_NONE = 0,
-	NM_DEVICE_STATE_REASON_UNKNOWN = 1,
-	NM_DEVICE_STATE_REASON_NOW_MANAGED = 2,
-	NM_DEVICE_STATE_REASON_NOW_UNMANAGED = 3,
-	NM_DEVICE_STATE_REASON_CONFIG_FAILED = 4,
-	NM_DEVICE_STATE_REASON_IP_CONFIG_UNAVAILABLE = 5,
-	NM_DEVICE_STATE_REASON_IP_CONFIG_EXPIRED = 6,
-	NM_DEVICE_STATE_REASON_NO_SECRETS = 7,
-	NM_DEVICE_STATE_REASON_SUPPLICANT_DISCONNECT = 8,
-	NM_DEVICE_STATE_REASON_SUPPLICANT_CONFIG_FAILED = 9,
-	NM_DEVICE_STATE_REASON_SUPPLICANT_FAILED = 10,
-	NM_DEVICE_STATE_REASON_SUPPLICANT_TIMEOUT = 11,
-	NM_DEVICE_STATE_REASON_PPP_START_FAILED = 12,
-	NM_DEVICE_STATE_REASON_PPP_DISCONNECT = 13,
-	NM_DEVICE_STATE_REASON_PPP_FAILED = 14,
-	NM_DEVICE_STATE_REASON_DHCP_START_FAILED = 15,
-	NM_DEVICE_STATE_REASON_DHCP_ERROR = 16,
-	NM_DEVICE_STATE_REASON_DHCP_FAILED = 17,
-	NM_DEVICE_STATE_REASON_SHARED_START_FAILED = 18,
-	NM_DEVICE_STATE_REASON_SHARED_FAILED = 19,
-	NM_DEVICE_STATE_REASON_AUTOIP_START_FAILED = 20,
-	NM_DEVICE_STATE_REASON_AUTOIP_ERROR = 21,
-	NM_DEVICE_STATE_REASON_AUTOIP_FAILED = 22,
-	NM_DEVICE_STATE_REASON_MODEM_BUSY = 23,
-	NM_DEVICE_STATE_REASON_MODEM_NO_DIAL_TONE = 24,
-	NM_DEVICE_STATE_REASON_MODEM_NO_CARRIER = 25,
-	NM_DEVICE_STATE_REASON_MODEM_DIAL_TIMEOUT = 26,
-	NM_DEVICE_STATE_REASON_MODEM_DIAL_FAILED = 27,
-	NM_DEVICE_STATE_REASON_MODEM_INIT_FAILED = 28,
-	NM_DEVICE_STATE_REASON_GSM_APN_FAILED = 29,
+	NM_DEVICE_STATE_REASON_NONE                           = 0,
+	NM_DEVICE_STATE_REASON_UNKNOWN                        = 1,
+	NM_DEVICE_STATE_REASON_NOW_MANAGED                    = 2,
+	NM_DEVICE_STATE_REASON_NOW_UNMANAGED                  = 3,
+	NM_DEVICE_STATE_REASON_CONFIG_FAILED                  = 4,
+	NM_DEVICE_STATE_REASON_IP_CONFIG_UNAVAILABLE          = 5,
+	NM_DEVICE_STATE_REASON_IP_CONFIG_EXPIRED              = 6,
+	NM_DEVICE_STATE_REASON_NO_SECRETS                     = 7,
+	NM_DEVICE_STATE_REASON_SUPPLICANT_DISCONNECT          = 8,
+	NM_DEVICE_STATE_REASON_SUPPLICANT_CONFIG_FAILED       = 9,
+	NM_DEVICE_STATE_REASON_SUPPLICANT_FAILED              = 10,
+	NM_DEVICE_STATE_REASON_SUPPLICANT_TIMEOUT             = 11,
+	NM_DEVICE_STATE_REASON_PPP_START_FAILED               = 12,
+	NM_DEVICE_STATE_REASON_PPP_DISCONNECT                 = 13,
+	NM_DEVICE_STATE_REASON_PPP_FAILED                     = 14,
+	NM_DEVICE_STATE_REASON_DHCP_START_FAILED              = 15,
+	NM_DEVICE_STATE_REASON_DHCP_ERROR                     = 16,
+	NM_DEVICE_STATE_REASON_DHCP_FAILED                    = 17,
+	NM_DEVICE_STATE_REASON_SHARED_START_FAILED            = 18,
+	NM_DEVICE_STATE_REASON_SHARED_FAILED                  = 19,
+	NM_DEVICE_STATE_REASON_AUTOIP_START_FAILED            = 20,
+	NM_DEVICE_STATE_REASON_AUTOIP_ERROR                   = 21,
+	NM_DEVICE_STATE_REASON_AUTOIP_FAILED                  = 22,
+	NM_DEVICE_STATE_REASON_MODEM_BUSY                     = 23,
+	NM_DEVICE_STATE_REASON_MODEM_NO_DIAL_TONE             = 24,
+	NM_DEVICE_STATE_REASON_MODEM_NO_CARRIER               = 25,
+	NM_DEVICE_STATE_REASON_MODEM_DIAL_TIMEOUT             = 26,
+	NM_DEVICE_STATE_REASON_MODEM_DIAL_FAILED              = 27,
+	NM_DEVICE_STATE_REASON_MODEM_INIT_FAILED              = 28,
+	NM_DEVICE_STATE_REASON_GSM_APN_FAILED                 = 29,
 	NM_DEVICE_STATE_REASON_GSM_REGISTRATION_NOT_SEARCHING = 30,
-	NM_DEVICE_STATE_REASON_GSM_REGISTRATION_DENIED = 31,
-	NM_DEVICE_STATE_REASON_GSM_REGISTRATION_TIMEOUT = 32,
-	NM_DEVICE_STATE_REASON_GSM_REGISTRATION_FAILED = 33,
-	NM_DEVICE_STATE_REASON_GSM_PIN_CHECK_FAILED = 34,
-	NM_DEVICE_STATE_REASON_FIRMWARE_MISSING = 35,
-	NM_DEVICE_STATE_REASON_REMOVED = 36,
-	NM_DEVICE_STATE_REASON_SLEEPING = 37,
-	NM_DEVICE_STATE_REASON_CONNECTION_REMOVED = 38,
-	NM_DEVICE_STATE_REASON_USER_REQUESTED = 39,
-	NM_DEVICE_STATE_REASON_CARRIER = 40,
-	NM_DEVICE_STATE_REASON_CONNECTION_ASSUMED = 41,
-	NM_DEVICE_STATE_REASON_SUPPLICANT_AVAILABLE = 42,
-	NM_DEVICE_STATE_REASON_MODEM_NOT_FOUND = 43,
-	NM_DEVICE_STATE_REASON_BT_FAILED = 44,
-	NM_DEVICE_STATE_REASON_GSM_SIM_NOT_INSERTED = 45,
-	NM_DEVICE_STATE_REASON_GSM_SIM_PIN_REQUIRED = 46,
-	NM_DEVICE_STATE_REASON_GSM_SIM_PUK_REQUIRED = 47,
-	NM_DEVICE_STATE_REASON_GSM_SIM_WRONG = 48,
-	NM_DEVICE_STATE_REASON_INFINIBAND_MODE = 49,
-	NM_DEVICE_STATE_REASON_DEPENDENCY_FAILED = 50,
-	NM_DEVICE_STATE_REASON_BR2684_FAILED = 51,
-	NM_DEVICE_STATE_REASON_MODEM_MANAGER_UNAVAILABLE = 52,
-	NM_DEVICE_STATE_REASON_SSID_NOT_FOUND = 53,
-	NM_DEVICE_STATE_REASON_SECONDARY_CONNECTION_FAILED = 54,
-	NM_DEVICE_STATE_REASON_DCB_FCOE_FAILED = 55,
-	NM_DEVICE_STATE_REASON_TEAMD_CONTROL_FAILED = 56,
-	NM_DEVICE_STATE_REASON_MODEM_FAILED = 57,
-	NM_DEVICE_STATE_REASON_MODEM_AVAILABLE = 58,
-	NM_DEVICE_STATE_REASON_SIM_PIN_INCORRECT = 59,
-	NM_DEVICE_STATE_REASON_NEW_ACTIVATION = 60,
-	NM_DEVICE_STATE_REASON_PARENT_CHANGED = 61,
-	NM_DEVICE_STATE_REASON_PARENT_MANAGED_CHANGED = 62,
+	NM_DEVICE_STATE_REASON_GSM_REGISTRATION_DENIED        = 31,
+	NM_DEVICE_STATE_REASON_GSM_REGISTRATION_TIMEOUT       = 32,
+	NM_DEVICE_STATE_REASON_GSM_REGISTRATION_FAILED        = 33,
+	NM_DEVICE_STATE_REASON_GSM_PIN_CHECK_FAILED           = 34,
+	NM_DEVICE_STATE_REASON_FIRMWARE_MISSING               = 35,
+	NM_DEVICE_STATE_REASON_REMOVED                        = 36,
+	NM_DEVICE_STATE_REASON_SLEEPING                       = 37,
+	NM_DEVICE_STATE_REASON_CONNECTION_REMOVED             = 38,
+	NM_DEVICE_STATE_REASON_USER_REQUESTED                 = 39,
+	NM_DEVICE_STATE_REASON_CARRIER                        = 40,
+	NM_DEVICE_STATE_REASON_CONNECTION_ASSUMED             = 41,
+	NM_DEVICE_STATE_REASON_SUPPLICANT_AVAILABLE           = 42,
+	NM_DEVICE_STATE_REASON_MODEM_NOT_FOUND                = 43,
+	NM_DEVICE_STATE_REASON_BT_FAILED                      = 44,
+	NM_DEVICE_STATE_REASON_GSM_SIM_NOT_INSERTED           = 45,
+	NM_DEVICE_STATE_REASON_GSM_SIM_PIN_REQUIRED           = 46,
+	NM_DEVICE_STATE_REASON_GSM_SIM_PUK_REQUIRED           = 47,
+	NM_DEVICE_STATE_REASON_GSM_SIM_WRONG                  = 48,
+	NM_DEVICE_STATE_REASON_INFINIBAND_MODE                = 49,
+	NM_DEVICE_STATE_REASON_DEPENDENCY_FAILED              = 50,
+	NM_DEVICE_STATE_REASON_BR2684_FAILED                  = 51,
+	NM_DEVICE_STATE_REASON_MODEM_MANAGER_UNAVAILABLE      = 52,
+	NM_DEVICE_STATE_REASON_SSID_NOT_FOUND                 = 53,
+	NM_DEVICE_STATE_REASON_SECONDARY_CONNECTION_FAILED    = 54,
+	NM_DEVICE_STATE_REASON_DCB_FCOE_FAILED                = 55,
+	NM_DEVICE_STATE_REASON_TEAMD_CONTROL_FAILED           = 56,
+	NM_DEVICE_STATE_REASON_MODEM_FAILED                   = 57,
+	NM_DEVICE_STATE_REASON_MODEM_AVAILABLE                = 58,
+	NM_DEVICE_STATE_REASON_SIM_PIN_INCORRECT              = 59,
+	NM_DEVICE_STATE_REASON_NEW_ACTIVATION                 = 60,
+	NM_DEVICE_STATE_REASON_PARENT_CHANGED                 = 61,
+	NM_DEVICE_STATE_REASON_PARENT_MANAGED_CHANGED         = 62,
 } NMDeviceStateReason;
 
 /**
@@ -578,11 +579,11 @@ typedef enum {
  * network.
  **/
 typedef enum {
-	NM_ACTIVE_CONNECTION_STATE_UNKNOWN = 0,
-	NM_ACTIVE_CONNECTION_STATE_ACTIVATING,
-	NM_ACTIVE_CONNECTION_STATE_ACTIVATED,
-	NM_ACTIVE_CONNECTION_STATE_DEACTIVATING,
-	NM_ACTIVE_CONNECTION_STATE_DEACTIVATED
+	NM_ACTIVE_CONNECTION_STATE_UNKNOWN      = 0,
+	NM_ACTIVE_CONNECTION_STATE_ACTIVATING   = 1,
+	NM_ACTIVE_CONNECTION_STATE_ACTIVATED    = 2,
+	NM_ACTIVE_CONNECTION_STATE_DEACTIVATING = 3,
+	NM_ACTIVE_CONNECTION_STATE_DEACTIVATED  = 4,
 } NMActiveConnectionState;
 
 /**
@@ -609,14 +610,14 @@ typedef enum {
  * #NMSecretAgentGetSecretsFlags values modify the behavior of a GetSecrets request.
  */
 typedef enum { /*< flags >*/
-	NM_SECRET_AGENT_GET_SECRETS_FLAG_NONE = 0x0,
+	NM_SECRET_AGENT_GET_SECRETS_FLAG_NONE              = 0x0,
 	NM_SECRET_AGENT_GET_SECRETS_FLAG_ALLOW_INTERACTION = 0x1,
-	NM_SECRET_AGENT_GET_SECRETS_FLAG_REQUEST_NEW = 0x2,
-	NM_SECRET_AGENT_GET_SECRETS_FLAG_USER_REQUESTED = 0x4,
+	NM_SECRET_AGENT_GET_SECRETS_FLAG_REQUEST_NEW       = 0x2,
+	NM_SECRET_AGENT_GET_SECRETS_FLAG_USER_REQUESTED    = 0x4,
 
 	/* Internal to NM; not part of the D-Bus API */
-	NM_SECRET_AGENT_GET_SECRETS_FLAG_ONLY_SYSTEM = 0x80000000,
-	NM_SECRET_AGENT_GET_SECRETS_FLAG_NO_ERRORS = 0x40000000,
+	NM_SECRET_AGENT_GET_SECRETS_FLAG_ONLY_SYSTEM       = 0x80000000,
+	NM_SECRET_AGENT_GET_SECRETS_FLAG_NO_ERRORS         = 0x40000000,
 } NMSecretAgentGetSecretsFlags;
 
 /**
@@ -629,33 +630,33 @@ typedef enum { /*< flags >*/
  * #NMSecretAgentCapabilities indicate various capabilities of the agent.
  */
 typedef enum /*< flags >*/ {
-	NM_SECRET_AGENT_CAPABILITY_NONE = 0x0,
+	NM_SECRET_AGENT_CAPABILITY_NONE      = 0x0,
 	NM_SECRET_AGENT_CAPABILITY_VPN_HINTS = 0x1,
 
 	/* boundary value */
-	NM_SECRET_AGENT_CAPABILITY_LAST = NM_SECRET_AGENT_CAPABILITY_VPN_HINTS
+	NM_SECRET_AGENT_CAPABILITY_LAST      = NM_SECRET_AGENT_CAPABILITY_VPN_HINTS,
 } NMSecretAgentCapabilities;
 
 #ifndef NM_VERSION_H
 #undef NM_AVAILABLE_IN_1_2
 #endif
 
-#define NM_LLDP_ATTR_DESTINATION "destination"
-#define NM_LLDP_ATTR_CHASSIS_ID_TYPE "chassis-id-type"
-#define NM_LLDP_ATTR_CHASSIS_ID "chassis-id"
-#define NM_LLDP_ATTR_PORT_ID_TYPE "port-id-type"
-#define NM_LLDP_ATTR_PORT_ID "port-id"
-#define NM_LLDP_ATTR_PORT_DESCRIPTION "port-description"
-#define NM_LLDP_ATTR_SYSTEM_NAME "system-name"
-#define NM_LLDP_ATTR_SYSTEM_DESCRIPTION "system-description"
-#define NM_LLDP_ATTR_SYSTEM_CAPABILITIES "system-capabilities"
-#define NM_LLDP_ATTR_IEEE_802_1_PVID "ieee-802-1-pvid"
-#define NM_LLDP_ATTR_IEEE_802_1_PPVID "ieee-802-1-ppvid"
-#define NM_LLDP_ATTR_IEEE_802_1_PPVID_FLAGS "ieee-802-1-ppvid-flags"
-#define NM_LLDP_ATTR_IEEE_802_1_VID "ieee-802-1-vid"
-#define NM_LLDP_ATTR_IEEE_802_1_VLAN_NAME "ieee-802-1-vlan-name"
+#define NM_LLDP_ATTR_DESTINATION             "destination"
+#define NM_LLDP_ATTR_CHASSIS_ID_TYPE         "chassis-id-type"
+#define NM_LLDP_ATTR_CHASSIS_ID              "chassis-id"
+#define NM_LLDP_ATTR_PORT_ID_TYPE            "port-id-type"
+#define NM_LLDP_ATTR_PORT_ID                 "port-id"
+#define NM_LLDP_ATTR_PORT_DESCRIPTION        "port-description"
+#define NM_LLDP_ATTR_SYSTEM_NAME             "system-name"
+#define NM_LLDP_ATTR_SYSTEM_DESCRIPTION      "system-description"
+#define NM_LLDP_ATTR_SYSTEM_CAPABILITIES     "system-capabilities"
+#define NM_LLDP_ATTR_IEEE_802_1_PVID         "ieee-802-1-pvid"
+#define NM_LLDP_ATTR_IEEE_802_1_PPVID        "ieee-802-1-ppvid"
+#define NM_LLDP_ATTR_IEEE_802_1_PPVID_FLAGS  "ieee-802-1-ppvid-flags"
+#define NM_LLDP_ATTR_IEEE_802_1_VID          "ieee-802-1-vid"
+#define NM_LLDP_ATTR_IEEE_802_1_VLAN_NAME    "ieee-802-1-vlan-name"
 
-#define NM_LLDP_DEST_NEAREST_BRIDGE "nearest-bridge"
+#define NM_LLDP_DEST_NEAREST_BRIDGE          "nearest-bridge"
 #define NM_LLDP_DEST_NEAREST_NON_TPMR_BRIDGE "nearest-non-tpmr-bridge"
 #define NM_LLDP_DEST_NEAREST_CUSTOMER_BRIDGE "nearest-customer-bridge"
 
@@ -689,4 +690,38 @@ typedef enum {
 	NM_IP_TUNNEL_MODE_VTI6        = 9,
 } NMIPTunnelMode;
 
+
+/**
+ * NMCheckpointCreateFlags:
+ * @NM_CHECKPOINT_CREATE_FLAG_NONE: no flags
+ * @NM_CHECKPOINT_CREATE_FLAG_DESTROY_ALL: when creating
+ *   a new checkpoint, destroy all existing ones.
+ *
+ * The flags for CheckpointCreate call
+ *
+ * Since: 1.4
+ */
+typedef enum { /*< skip >*/
+	NM_CHECKPOINT_CREATE_FLAG_NONE              = 0,
+	NM_CHECKPOINT_CREATE_FLAG_DESTROY_ALL       = 0x01,
+} NMCheckpointCreateFlags;
+
+/**
+ * NMRollbackResult:
+ * @NM_ROLLBACK_RESULT_OK: the rollback succeeded.
+ * @NM_ROLLBACK_RESULT_ERR_NO_DEVICE: the device no longer exists.
+ * @NM_ROLLBACK_RESULT_ERR_DEVICE_UNMANAGED: the device is now unmanaged.
+ * @NM_ROLLBACK_RESULT_ERR_FAILED: other errors during rollback.
+ *
+ * The result of a checkpoint Rollback() operation for a specific device.
+ *
+ * Since: 1.4
+ **/
+typedef enum { /*< skip >*/
+	NM_ROLLBACK_RESULT_OK                   = 0,
+	NM_ROLLBACK_RESULT_ERR_NO_DEVICE        = 1,
+	NM_ROLLBACK_RESULT_ERR_DEVICE_UNMANAGED = 2,
+	NM_ROLLBACK_RESULT_ERR_FAILED           = 3,
+} NMRollbackResult;
+
 #endif /* __NM_DBUS_INTERFACE_H__ */
