@@ -19,15 +19,14 @@
  * Copyright 2007 - 2012 Red Hat, Inc.
  */
 
-#include "config.h"
+#include "nm-default.h"
 
 #include <string.h>
 
-#include <nm-setting-connection.h>
-#include <nm-setting-bluetooth.h>
-#include <nm-utils.h>
+#include "nm-setting-connection.h"
+#include "nm-setting-bluetooth.h"
+#include "nm-utils.h"
 
-#include "nm-default.h"
 #include "nm-device-bt.h"
 #include "nm-device-private.h"
 #include "nm-object-private.h"
