@@ -61,7 +61,7 @@
 #include "nmdbus-device.h"
 
 static GType _nm_device_decide_type (GVariant *value);
-gboolean connection_compatible (NMDevice *device, NMConnection *connection, GError **error);
+static gboolean connection_compatible (NMDevice *device, NMConnection *connection, GError **error);
 static NMLldpNeighbor *nm_lldp_neighbor_dup (NMLldpNeighbor *neighbor);
 
 G_DEFINE_TYPE_WITH_CODE (NMDevice, nm_device, NM_TYPE_OBJECT,
@@ -1722,6 +1722,7 @@ get_description (NMDevice *device)
 	char *pdown;
 	char *vdown;
 	GString *str;
+	GParamSpec *name_prop;
 
 	dev_product = nm_device_get_product (device);
 	priv->short_product = fixup_desc_string (dev_product);
@@ -1729,6 +1730,15 @@ get_description (NMDevice *device)
 	dev_vendor = nm_device_get_vendor (device);
 	priv->short_vendor = fixup_desc_string (dev_vendor);
 
+	/* Grab device's preferred name, if any */
+	name_prop = g_object_class_find_property (G_OBJECT_GET_CLASS (G_OBJECT (device)), "name");
+	if (name_prop) {
+		g_object_get (device, "name", &priv->description, NULL);
+		if (priv->description && priv->description[0])
+			return;
+		g_clear_pointer (&priv->description, g_free);
+	}
+
 	if (!dev_product || !dev_vendor) {
 		priv->description = g_strdup (nm_device_get_iface (device));
 		return;
@@ -1901,6 +1911,7 @@ get_bus_name (NMDevice *device)
 		 */
 		priv->bus_name = g_strdup ("");
 	}
+	g_object_unref (udevice);
 
 out:
 	if (*priv->bus_name)
@@ -2329,6 +2340,9 @@ nm_device_reapply_finish (NMDevice *device,
  * Returns: (transfer full): a %NMConnection with the currently applied settings
  *   or %NULL on error.
  *
+ * The connection is as received from D-Bus and might not validate according
+ * to nm_connection_verify().
+ *
  * Since: 1.2
  **/
 NMConnection *
@@ -2355,7 +2369,7 @@ nm_device_get_applied_connection (NMDevice *device,
 		return NULL;
 	}
 
-	connection = nm_simple_connection_new_from_dbus (dict, error);
+	connection = _nm_simple_connection_new_from_dbus (dict, NM_SETTING_PARSE_FLAGS_BEST_EFFORT, error);
 	if (!connection)
 		return NULL;
 
@@ -2397,7 +2411,7 @@ device_get_applied_connection_cb (GObject *proxy,
 		goto out;
 	}
 
-	connection = nm_simple_connection_new_from_dbus (dict, &error);
+	connection = _nm_simple_connection_new_from_dbus (dict, NM_SETTING_PARSE_FLAGS_BEST_EFFORT, &error);
 	if (!connection) {
 		g_simple_async_result_take_error (simple, error);
 		goto out;
@@ -2457,6 +2471,9 @@ nm_device_get_applied_connection_async  (NMDevice *device,
  * Returns: (transfer full): a currently applied %NMConnection or %NULL in case
  *   of error.
  *
+ * The connection is as received from D-Bus and might not validate according
+ * to nm_connection_verify().
+ *
  * Since: 1.2
  **/
 NMConnection *
@@ -2712,7 +2729,7 @@ nm_device_connection_valid (NMDevice *device, NMConnection *connection)
 	return nm_device_connection_compatible (device, connection, NULL);
 }
 
-gboolean
+static gboolean
 connection_compatible (NMDevice *device, NMConnection *connection, GError **error)
 {
 	const char *config_iface, *device_iface;
