@@ -26,6 +26,7 @@
 #include "nm-dbus-interface.h"
 #include "nm-utils.h"
 #include "nm-setting-connection.h"
+#include "nm-core-internal.h"
 
 #include "nm-remote-connection.h"
 #include "nm-remote-connection-private.h"
@@ -563,14 +564,11 @@ replace_settings (NMRemoteConnection *self, GVariant *new_settings)
 {
 	GError *error = NULL;
 
-	if (!nm_connection_replace_settings (NM_CONNECTION (self), new_settings, &error)) {
-		g_warning ("%s: error updating connection %s settings: (%d) %s",
-		           __func__,
-		           nm_connection_get_path (NM_CONNECTION (self)),
-		           error ? error->code : -1,
-		           (error && error->message) ? error->message : "(unknown)");
+	if (!_nm_connection_replace_settings ((NMConnection *) self,
+	                                      new_settings,
+	                                      NM_SETTING_PARSE_FLAGS_BEST_EFFORT,
+	                                      &error))
 		g_clear_error (&error);
-	}
 }
 
 static void
@@ -780,6 +778,8 @@ get_property (GObject *object, guint prop_id,
 static void
 constructed (GObject *object)
 {
+	G_OBJECT_CLASS (nm_remote_connection_parent_class)->constructed (object);
+
 	nm_connection_set_path (NM_CONNECTION (object),
 	                        nm_object_get_path (NM_OBJECT (object)));
 }
