@@ -52,21 +52,16 @@ gboolean nmp_utils_mii_supports_carrier_detect (const char *ifname);
 
 const char *nmp_utils_udev_get_driver (GUdevDevice *device);
 
-guint32 nmp_utils_lifetime_rebase_relative_time_on_now (guint32 timestamp,
-                                                        guint32 duration,
-                                                        guint32 now,
-                                                        guint32 padding);
-
-gboolean nmp_utils_lifetime_get (guint32 timestamp,
-                                 guint32 lifetime,
-                                 guint32 preferred,
-                                 guint32 now,
-                                 guint32 padding,
-                                 guint32 *out_lifetime,
-                                 guint32 *out_preferred);
-
 gboolean nmp_utils_device_exists (const char *name);
 
-gboolean nmp_utils_ip4_address_is_link_local (in_addr_t addr);
+NMIPConfigSource nmp_utils_ip_config_source_from_rtprot (guint8 rtprot) _nm_const;
+guint8           nmp_utils_ip_config_source_coerce_to_rtprot   (NMIPConfigSource source) _nm_const;
+NMIPConfigSource nmp_utils_ip_config_source_coerce_from_rtprot (NMIPConfigSource source) _nm_const;
+NMIPConfigSource nmp_utils_ip_config_source_round_trip_rtprot  (NMIPConfigSource source) _nm_const;
+const char *     nmp_utils_ip_config_source_to_string (NMIPConfigSource source, char *buf, gsize len);
+
+int nmp_utils_sysctl_open_netdir (int ifindex,
+                                  const char *ifname_guess,
+                                  char *out_ifname);
 
 #endif /* __NM_PLATFORM_UTILS_H__ */
